/*
 *  Uzebox Default Patches
 *  Copyright (C) 2008  Alec Bourque
 *
 *  This program is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
*/

/*
	Patches are made of a command stream made of 3 bytes per command:
		1=delta time
		2=command
		3=command parameter

	Patches must start with 1 byte describing the sound type:
		0=wave channel (i.e.; channel 0,1 and 2)
		1=noise channel (channel 3)
		2=PCM (channel 3)
		->For type=2 two more byte follows in order: sample adress low byte, sample adress hi byte

	It must end with <0,PATCH_END> and this command takes
	only two bytes (no parameter).
*/



//INST: lead fast env       Channel 1....
  const char patch00[] PROGMEM ={ 
  0,PC_WAVE,4,
  0,PC_ENV_SPEED,-35,
  0,PATCH_END
};

//INST: lead slow env       Channel 2....
const char patch01[] PROGMEM ={ 
  0,PC_WAVE,4,
  0,PC_ENV_SPEED,-10,
  0,PATCH_END
 };



//INST: organ
const char patch02[] PROGMEM ={	
  0,PC_WAVE,8,
  1,PC_ENV_VOL,200, 
  1,PC_NOTE_HOLD,0,
  1,PC_ENV_SPEED,-25,
  0,PATCH_END
};

const char SFX_red[] PROGMEM ={	
  0,PC_WAVE,8,              //Tell the kernel which wave we will be working off.
  0,PC_TREMOLO_LEVEL,0x90,     
  0,PC_TREMOLO_RATE,40, 
  0,PC_NOTE_DOWN,30,
  1,PC_ENV_VOL,200, 
  1,PC_ENV_SPEED,-10,
  10,PC_PITCH,10,            //We want to set the pitch to note 69. The first argument tells the kernel we want this to happen 1 frame after we call TriggerFx()
  1,PC_NOTE_CUT,0,         //After the note above plays for 1 frame, stop the effect entirely
  0,PATCH_END              //End of patch
};

const char SFX_blue[] PROGMEM ={	
  0,PC_WAVE,8,              //Tell the kernel which wave we will be working off.
  0,PC_TREMOLO_LEVEL,0x90,     
  0,PC_TREMOLO_RATE,40, 
  0,PC_NOTE_DOWN,25,
  1,PC_ENV_VOL,200, 
  1,PC_ENV_SPEED,-10,
  10,PC_PITCH,10,            //We want to set the pitch to note 69. The first argument tells the kernel we want this to happen 1 frame after we call TriggerFx()
  1,PC_NOTE_CUT,0,         //After the note above plays for 1 frame, stop the effect entirely
  0,PATCH_END              //End of patch
};

const char SFX_green[] PROGMEM ={	
  0,PC_WAVE,8,              //Tell the kernel which wave we will be working off.
  0,PC_TREMOLO_LEVEL,0x90,     
  0,PC_TREMOLO_RATE,40, 
  0,PC_NOTE_DOWN,20,
  1,PC_ENV_VOL,200, 
  1,PC_ENV_SPEED,-10,
  10,PC_PITCH,10,            //We want to set the pitch to note 69. The first argument tells the kernel we want this to happen 1 frame after we call TriggerFx()
  1,PC_NOTE_CUT,0,         //After the note above plays for 1 frame, stop the effect entirely
  0,PATCH_END              //End of patch
};

const char SFX_yellow[] PROGMEM ={	
  0,PC_WAVE,8,              //Tell the kernel which wave we will be working off.
  0,PC_TREMOLO_LEVEL,0x90,     
  0,PC_TREMOLO_RATE,40, 
  0,PC_NOTE_DOWN,15,
  1,PC_ENV_VOL,200, 
  1,PC_ENV_SPEED,-10,
  10,PC_PITCH,10,            //We want to set the pitch to note 69. The first argument tells the kernel we want this to happen 1 frame after we call TriggerFx()
  1,PC_NOTE_CUT,0,         //After the note above plays for 1 frame, stop the effect entirely
  0,PATCH_END              //End of patch
};


const char SFX_failed[] PROGMEM ={	
0,PC_WAVE,8,
0,PC_ENV_SPEED,-5,
0,PC_TREMOLO_LEVEL,0x90,     
0,PC_TREMOLO_RATE,60, 
0,PC_PITCH,90,
5,PC_NOTE_DOWN,3,
5,PC_NOTE_DOWN,4,
5,PC_NOTE_DOWN,5,
5,PC_NOTE_DOWN,6,
5,PC_NOTE_DOWN,7,
5,PC_NOTE_DOWN,8,
5,PC_NOTE_DOWN,9,
5,PC_NOTE_CUT,0,
0,PATCH_END
};




const struct PatchStruct patches[] PROGMEM = {
{0,NULL,patch00,0,0},
{0,NULL,patch01,0,0},
{0,NULL,patch02,0,0},
{0,NULL,SFX_red,0,0},
{0,NULL,SFX_blue,0,0},
{0,NULL,SFX_green,0,0},
{0,NULL,SFX_yellow,0,0},
{0,NULL,SFX_failed,0,0},
};
